@@ -21,43 +21,43 @@ our $LAST;
 our $WARN;
 our $DIE;
 
-=head1 VERSION
-
-Version 0.06
-
 =head1 NAME
 
 Log::WarnDie - Log standard Perl warnings and errors on a log handler
 
+=head1 VERSION
+
+Version 0.07
+
 =head1 SYNOPSIS
 
- use Log::WarnDie; # install to be used later
+    use Log::WarnDie; # install to be used later
 
- my $dispatcher = Log::Dispatch->new;       # can be any dispatcher!
- $dispatcher->add( Log::Dispatch::Foo->new( # whatever output you like
-  name      => 'foo',
-  min_level => 'info',
- ) );
+    my $dispatcher = Log::Dispatch->new;       # can be any dispatcher!
+    $dispatcher->add( Log::Dispatch::Foo->new( # whatever output you like
+     name      => 'foo',
+     min_level => 'info',
+    ) );
 
- use Log::WarnDie $dispatcher; # activate later
+    use Log::WarnDie $dispatcher; # activate later
 
- Log::WarnDie->dispatcher( $dispatcher ); # same
+    Log::WarnDie->dispatcher( $dispatcher ); # same
 
- warn "This is a warning";       # now also dispatched
- die "Sorry it didn't work out"; # now also dispatched
+    warn "This is a warning";       # now also dispatched
+    die "Sorry it didn't work out"; # now also dispatched
 
- no Log::WarnDie; # deactivate later
+    no Log::WarnDie; # deactivate later
 
- Log::WarnDie->dispatcher( undef ); # same
+    Log::WarnDie->dispatcher( undef ); # same
 
- warn "This is a warning"; # no longer dispatched
- die "Sorry it didn't work out"; # no longer dispatched
+    warn "This is a warning"; # no longer dispatched
+    die "Sorry it didn't work out"; # no longer dispatched
 
 =head1 DESCRIPTION
 
 The "Log::WarnDie" module offers a logging alternative for standard
 Perl core functions.  This allows you to use the features of e.g.
-L<Log::Dispatch> or L<Log::Log4perl> B<without> having to make extensive
+L<Log::Dispatch>, L<Log::Any> or L<Log::Log4perl> B<without> having to make extensive
 changes to your source code.
 
 When loaded, it installs a __WARN__ and __DIE__ handler and intercepts any
@@ -73,7 +73,7 @@ enabled at any time for critical sections of code.
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SUBROUTINES/METHODS
 
@@ -116,7 +116,9 @@ sub PRINT {
          unless $LAST and @$LAST == @_ and join( '',@$LAST ) eq join( '',@_ );
         undef $LAST;
     }
-    print $STDERR @_;
+    if($STDERR) {
+	print $STDERR @_;
+    }
 } #PRINT
 
 #---------------------------------------------------------------------------
@@ -141,9 +143,54 @@ sub PRINTF {
          unless $LAST and @$LAST == @_ and join( '',@$LAST ) eq join( '',@_ );
         undef $LAST;
     }
-    printf $STDERR @_;
-} #PRINT
+    if($STDERR) {
+	printf $STDERR @_;
+    }
+} #PRINTF
 
+#---------------------------------------------------------------------------
+# CLOSE
+#
+# Called whenever something tries to close STDERR
+#
+#  IN: 1 blessed object returned by TIEHANDLE
+#      2..N whatever was needed to be printed
+
+sub CLOSE {
+
+# Lose the object
+# If there is a dispatcher
+#  Put it in the log handler if not the same as last time
+#  Reset the flag
+# Make sure it appears on the original STDERR as well
+
+    my $keep = $STDERR;
+    $STDERR = undef;
+    close $keep;	# So that the return status can be checked
+} #CLOSE
+
+#---------------------------------------------------------------------------
+# OPEN
+#
+# Called whenever something tries to (re)open STDERR
+#
+#  IN: 1 blessed object returned by TIEHANDLE
+#      2..N whatever was needed to be printed
+
+sub OPEN {
+
+# Lose the object
+# If there is a dispatcher
+#  Put it in the log handler if not the same as last time
+#  Reset the flag
+# Make sure it appears on the original STDERR as well
+
+	shift;
+	my $arg1 = shift;
+	my $arg2 = shift;
+
+	open($STDERR, $arg1, $arg2);
+} #OPEN
 #---------------------------------------------------------------------------
 # At compile time
 #  Create new handle
@@ -184,7 +231,6 @@ BEGIN {
 #   Executes the standard system die() or whatever was there before
 
     $DIE = $SIG{__DIE__};
-    ::diag(ref($DISPATCHER));
     $SIG{__DIE__} = sub {
         if ($DISPATCHER) {
             $LAST = \@_;
@@ -312,11 +358,9 @@ the real use of this module only comes into view when such a module B<is>
 installed.  Please note that for testing this module, you will need the
 L<Log::Dispatch::Buffer> module to also be available.
 
-An alternate logger may be L<Log::Log4perl>, although this has not been tested
-by the author.  Any object that provides a C<warning>, C<error> and C<critical>
-method, will operate with this module.
-Log4perl does not the message 'critical', so it will not work.
-A wishlist request has been sent (RT121065).
+This module has been tested with
+L<Log::Dispatch>, L<Log::Any> and L<Log::Log4perl> B<without>.
+In principle any object which recognises C<warning>, C<error> and C<critical> should work.
 
 =head2 eval
 
